@@ -79,8 +79,13 @@ def totimestamp(dt, epoch=datetime.datetime(1970,1,1,0,0,0,0,pytz.UTC)):
     try:
         td=dt - epoch
     except TypeError:
-        dt = pytz.utc.localize(dt)
-        td = dt - epoch
+        try:
+            dt = pytz.utc.localize(dt)
+            td = dt - epoch
+        except AttributeError:
+            td = arrow.get(dt)
+            return tt.timestamp + tt.microsecond/10.**6
+
     # return td.total_seconds()
     return (td.microseconds + (td.seconds + td.days * 86400) * 10**6) / 10**6
 
